pub struct DragPanButtons(/* private fields */);Expand description
Specifies which pointer buttons can be used to pan the scene by dragging.
Implementations
Sourceimpl DragPanButtons
impl DragPanButtons
Sourcepub const MIDDLE: DragPanButtons
pub const MIDDLE: DragPanButtons
Sourcepub const EXTRA_1: DragPanButtons
pub const EXTRA_1: DragPanButtons
Sourcepub const EXTRA_2: DragPanButtons
pub const EXTRA_2: DragPanButtons
Sourceimpl DragPanButtons
impl DragPanButtons
Sourcepub const fn empty() -> DragPanButtons
pub const fn empty() -> DragPanButtons
Get a flags value with all bits unset.
Sourcepub const fn all() -> DragPanButtons
pub const fn all() -> DragPanButtons
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<DragPanButtons>
pub const fn from_bits(bits: u8) -> Option<DragPanButtons>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> DragPanButtons
pub const fn from_bits_truncate(bits: u8) -> DragPanButtons
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> DragPanButtons
pub const fn from_bits_retain(bits: u8) -> DragPanButtons
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DragPanButtons>
pub fn from_name(name: &str) -> Option<DragPanButtons>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DragPanButtons) -> bool
pub const fn intersects(&self, other: DragPanButtons) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: DragPanButtons) -> bool
pub const fn contains(&self, other: DragPanButtons) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: DragPanButtons)
pub fn insert(&mut self, other: DragPanButtons)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: DragPanButtons)
pub fn remove(&mut self, other: DragPanButtons)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DragPanButtons)
pub fn toggle(&mut self, other: DragPanButtons)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: DragPanButtons, value: bool)
pub fn set(&mut self, other: DragPanButtons, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: DragPanButtons) -> DragPanButtons
pub const fn intersection(self, other: DragPanButtons) -> DragPanButtons
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: DragPanButtons) -> DragPanButtons
pub const fn union(self, other: DragPanButtons) -> DragPanButtons
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: DragPanButtons) -> DragPanButtons
pub const fn difference(self, other: DragPanButtons) -> DragPanButtons
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: DragPanButtons) -> DragPanButtons
pub const fn symmetric_difference(self, other: DragPanButtons) -> DragPanButtons
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> DragPanButtons
pub const fn complement(self) -> DragPanButtons
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl DragPanButtons
impl DragPanButtons
Sourcepub const fn iter(&self) -> Iter<DragPanButtons> ⓘ
pub const fn iter(&self) -> Iter<DragPanButtons> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DragPanButtons> ⓘ
pub const fn iter_names(&self) -> IterNames<DragPanButtons> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.