pub struct TextureOptions {
pub magnification: TextureFilter,
pub minification: TextureFilter,
pub wrap_mode: TextureWrapMode,
pub mipmap_mode: Option<TextureFilter>,
}Expand description
How the texture texels are filtered.
Fields
magnification: TextureFilterHow to filter when magnifying (when texels are larger than pixels).
minification: TextureFilterHow to filter when minifying (when texels are smaller than pixels).
wrap_mode: TextureWrapModeHow to wrap the texture when the texture coordinates are outside the [0, 1] range.
mipmap_mode: Option<TextureFilter>How to filter between texture mipmaps.
Mipmaps ensures textures look smooth even when the texture is very small and pixels are much larger than individual texels.
Notes
- This may not be available on all backends (currently only
egui_glow).
Implementations
Sourceimpl TextureOptions
impl TextureOptions
Sourcepub const LINEAR: TextureOptions
pub const LINEAR: TextureOptions
Linear magnification and minification.
Sourcepub const NEAREST: TextureOptions
pub const NEAREST: TextureOptions
Nearest magnification and minification.
Sourcepub const LINEAR_REPEAT: TextureOptions
pub const LINEAR_REPEAT: TextureOptions
Linear magnification and minification, but with the texture repeated.
Sourcepub const LINEAR_MIRRORED_REPEAT: TextureOptions
pub const LINEAR_MIRRORED_REPEAT: TextureOptions
Linear magnification and minification, but with the texture mirrored and repeated.
Sourcepub const NEAREST_REPEAT: TextureOptions
pub const NEAREST_REPEAT: TextureOptions
Nearest magnification and minification, but with the texture repeated.
Sourcepub const NEAREST_MIRRORED_REPEAT: TextureOptions
pub const NEAREST_MIRRORED_REPEAT: TextureOptions
Nearest magnification and minification, but with the texture mirrored and repeated.
pub const fn with_mipmap_mode( self, mipmap_mode: Option<TextureFilter>, ) -> TextureOptions