pub struct FiniteTileLayerData { /* private fields */ }Expand description
The raw data of a FiniteTileLayer. Does not include a reference to its parent Map.
Implementations
Sourceimpl FiniteTileLayerData
impl FiniteTileLayerData
Sourcepub fn get_tile_data(&self, x: i32, y: i32) -> Option<&LayerTileData>
pub fn get_tile_data(&self, x: i32, y: i32) -> Option<&LayerTileData>
Obtains the tile data present at the position given.
If the position given is invalid or the position is empty, this function will return None.
If you want to get a Tile instead, use FiniteTileLayer::get_tile().